@@ -1,7 +1,7 @@
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-Moose/lib/Perl/Critic/Policy/Moose/RequireMakeImmutable.pm $
-#     $Date: 2008-10-30 09:36:26 -0500 (Thu, 30 Oct 2008) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic-Moose/lib/Perl/Critic/Policy/Moose/RequireMakeImmutable.pm $
+#     $Date: 2009-05-15 19:35:37 -0500 (Fri, 15 May 2009) $
 #   $Author: clonezone $
-# $Revision: 2845 $
+# $Revision: 3336 $
 
 package Perl::Critic::Policy::Moose::RequireMakeImmutable;
 
@@ -10,10 +10,9 @@ use 5.008;  # Moose's minimum version.
 use strict;
 use warnings;
 
-our $VERSION = '0.999_001';
+our $VERSION = '0.999_002';
 
 use Readonly ();
-use version ();
 
 use Perl::Critic::Utils qw< :booleans :severities >;
 use Perl::Critic::Utils::PPI qw< is_ppi_generic_statement >;
@@ -35,6 +34,7 @@ sub applies_to           { return 'PPI::Document'           }
 sub prepare_to_scan_document {
     my ($self, $document) = @_;
 
+    # Tech debt: duplicate code.
     return $document->find_any(
         sub {
             my (undef, $element) = @_;
@@ -53,7 +53,7 @@ sub prepare_to_scan_document {
 sub violates {
     my ($self, undef, $document) = @_;
 
-    my $imports = $document->find_any(
+    my $makes_immutable = $document->find_any(
         sub {
             my (undef, $element) = @_;
 
@@ -93,7 +93,7 @@ sub violates {
         }
     );
 
-    return if $imports;
+    return if $makes_immutable;
     return $self->violation($DESCRIPTION, $EXPLANATION, $document);
 } # end violates()
 
@@ -117,7 +117,7 @@ This policy is part of L<Perl::Critic::Moose>.
 =head1 VERSION
 
 This document describes Perl::Critic::Policy::Moose::RequireMakeImmutable
-version 0.999_001.
+version 0.999_002.
 
 
 =head1 DESCRIPTION
@@ -142,7 +142,9 @@ L<http://search.cpan.org/dist/Moose/lib/Moose/Cookbook/Basics/Recipe7.pod>
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
+Right now this assumes that you've only got one C<package> statement in your
+code.  It will get things wrong if you create multiple classes in a single
+file.
 
 Please report any bugs or feature requests to
 C<bug-perl-critic-moose@rt.cpan.org>, or through the web interface at
@@ -156,7 +158,7 @@ Elliot Shank  C<< <perl@galumph.com> >>
 
 =head1 COPYRIGHT
 
-Copyright (c)2008, Elliot Shank C<< <perl@galumph.com> >>. Some rights
+Copyright (c)2008-2009, Elliot Shank C<< <perl@galumph.com> >>. Some rights
 reserved.
 
 This module is free software; you can redistribute it and/or modify it under
